#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
@summary: A wrapper module around the pyvmomi module to simplify work and handling.

@author: Frank Brehm
@contact: frank@brehm-online.com
@copyright: © 2025 by Frank Brehm, Berlin
"""

__author__ = 'Frank Brehm <frank@brehm-online.com>'
__copyright__ = '(C) 2025 by Frank Brehm, Berlin'
__contact__ = 'frank@brehm-online.com'
__version__ = '1.5.0'
__license__ = 'LGPL3+'

# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
